# BMusic

Music animations combine music, 3D art, and computer generated animation.

BMusic is a Python library providing tools for procedural (program generated)
music animation.

[See an example here.](https://www.youtube.com/watch?v=ZE92NEA41nw)

![](https://github.com/phuang1024/bmusic/blob/master/examples/Debussy_ClairDeLune/example.jpg?raw=true)
